==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/AssigningPolarMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningPolarStyleEventArgsBaseDescriptionMetadata } from "./AssigningPolarStyleEventArgsBaseDescriptionMetadata";
import { AssigningPolarMarkerStyleEventArgsDescription } from "./AssigningPolarMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningPolarMarkerStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningPolarMarkerStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a == null) {
                AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningPolarMarkerStyleEventArgsDescriptionMetadata.c(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningPolarStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningPolarMarkerStyleEventArgsDescriptionMetadata.b(a);
            a.ad("AssigningPolarMarkerStyleEventArgs", () => new AssigningPolarMarkerStyleEventArgsDescription());
            a.ac("AssigningPolarMarkerStyleEventArgs", AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningPolarMarkerStyleEventArgsDescriptionMetadata, 'AssigningPolarMarkerStyleEventArgsDescriptionMetadata');
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningPolarMarkerStyleEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/AssigningPolarMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningPolarStyleEventArgsBaseDescriptionMetadata } from "./AssigningPolarStyleEventArgsBaseDescriptionMetadata";
import { AssigningPolarMarkerStyleEventArgsDescription } from "./AssigningPolarMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningPolarMarkerStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningPolarMarkerStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a == null) {
                AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningPolarMarkerStyleEventArgsDescriptionMetadata.c(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningPolarStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningPolarMarkerStyleEventArgsDescriptionMetadata.b(a);
            a.ae("AssigningPolarMarkerStyleEventArgs", () => new AssigningPolarMarkerStyleEventArgsDescription());
            a.ad("AssigningPolarMarkerStyleEventArgs", AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningPolarMarkerStyleEventArgsDescriptionMetadata, 'AssigningPolarMarkerStyleEventArgsDescriptionMetadata');
    AssigningPolarMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningPolarMarkerStyleEventArgsDescriptionMetadata;
})();
